@@ -11,6 +11,7 @@ SPEC data file standard control lines
 
 from collections import OrderedDict
 import datetime
+import logging
 import time
 
 from spec2nexus.plugin_core import ControlLineBase
@@ -34,6 +35,7 @@ from spec2nexus.utils import (
 from spec2nexus.writer import CONTAINER_CLASS
 
 
+logger = logging.getLogger(__name__)
 SCAN_DATA_KEY = "scan_data"
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -124,8 +126,6 @@ class SPEC_Date(ControlLineBase):
 
     def process(self, text, sdf_object, *args, **kws):
         text = strip_first_word(text)
-        # if isinstance(sdf_object, SpecDataFileScan):
-        #     sdf_object = sdf_object.header
         sp = text.split(" ")
         if len(sp) == 1:
             sdf_object.epoch = int(float(text))
@@ -139,10 +139,18 @@ class SPEC_Date(ControlLineBase):
             sdf_object.epoch = time.mktime(ts)
         if isinstance(sdf_object, SpecDataFileScan):
             sdf_object.addH5writer(self.key, self.writer)
-            if len(sdf_object.header.date.strip()) == 0:
-                sdf_object.header.date = text
-                sdf_object.header.epoch = sdf_object.epoch
-            # TODO: what if header date is greater than this scan's date?
+            header = sdf_object.header
+            if len(header.date.strip()) == 0:
+                header.date = text
+                header.epoch = sdf_object.epoch
+            else:
+                # Report if header date is greater than this scan's date.
+                if header.epoch > sdf_object.epoch:
+                    logger.warning(
+                        "Header epoch (%s) is younger than scan (%s)",
+                        str(datetime.datetime.fromtimestamp(header.epoch)),
+                        str(datetime.datetime.fromtimestamp(sdf_object.epoch)),
+                    )
 
     def writer(self, h5parent, writer, sdf_object, *args, **kws):
         """Describe how to store this data in an HDF5 NeXus file"""
@@ -224,7 +232,7 @@ class SPEC_Scan(ControlLineBase):
     def process(self, part, sdf, *args, **kws):
         if len(sdf.headers) == 0:
             # make a header if none exists now
-            raw = ""  # TODO: what default content to use?
+            raw = ""
             header = SpecDataFileHeader(raw, parent=sdf)
             sdf.headers.append(header)
         else:
@@ -917,6 +925,52 @@ class SPEC_HKL(ControlLineBase):
         write_dataset(h5parent, "Q", scan.Q, description=desc)
 
 
+class SPEC_UserResults(ControlLineBase):
+
+    """
+    **#R** -- Reserved for user results
+
+    IN-MEMORY REPRESENTATION
+
+    * (SpecDataFileHeader): **R**, [*str*]
+    * (SpecDataFileScan): **R**, [*str*]
+
+    HDF5/NeXus REPRESENTATION
+
+    * Within a *NXnote* group named **UserResults** in the *NXentry* group:
+      dataset(s) named **header_##** (from the SPEC data file header
+      section) or **item_##** (from the SPEC data file scan section),
+      such as */S1/UserResults/header_1* and  */S1/UserResults/item_5*
+    """
+
+    key = r"#R"
+    scan_attributes_defined = ["R"]
+
+    def process(self, text, sdf_object, *args, **kws):
+        text = strip_first_word(text)
+        if not hasattr(sdf_object, "R"):
+            sdf_object.R = []
+        sdf_object.R.append(text.strip())
+
+        sdf_object.addH5writer(self.key, self.writer)
+
+    def writer(self, h5parent, writer, sdf_object, *args, **kws):
+        """Describe how to store this data in an HDF5 NeXus file"""
+        desc = 'SPEC control line "#R: Reserved for user results"'
+        group = openGroup(
+            h5parent, "UserResults", "NXnote", description=desc
+        )
+        if isinstance(sdf_object, SpecDataFileHeader):
+            tag = "header"
+        else:
+            tag = "item"
+        for i, text in enumerate(sdf_object.R):
+            key = "%s_%d" % (tag, i + 1)
+            write_dataset(
+                group, key, text, description="#R line %d" % (i + 1)
+            )
+
+
 class SPEC_CountTime(ControlLineBase):
 
     """
@@ -957,7 +1011,7 @@ class SPEC_CountTime(ControlLineBase):
 class SPEC_UserReserved(ControlLineBase):
 
     """
-    **#U** -- Reserved for user
+    **#U** -- Reserved for user-defined information
 
     IN-MEMORY REPRESENTATION
 
